==> qt-creator-opensource-src-3.5.1.tar.gz: qt-creator-opensource-src-3.5.1/tests/unit/unittest/mockipclient.h <==
/****************************************************************************
**
** Copyright (C) 2015 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt.io/licensing
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://www.qt.io/licensing.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef MOCKIPCLIENT_H
#define MOCKIPCLIENT_H

#include <ipcclientinterface.h>

#include <gmock/gmock.h>
#include <gmock/gmock-matchers.h>
#include <gtest/gtest.h>
#include "gtest-qt-printing.h"

class MockIpcClient : public ClangBackEnd::IpcClientInterface {
 public:
  MOCK_METHOD0(alive,
      void());
  MOCK_METHOD1(echo,
      void(const ClangBackEnd::EchoCommand &command));
  MOCK_METHOD1(codeCompleted,
      void(const ClangBackEnd::CodeCompletedCommand &command));
  MOCK_METHOD1(translationUnitDoesNotExist,
      void(const ClangBackEnd::TranslationUnitDoesNotExistCommand &command));
  MOCK_METHOD1(projectPartsDoNotExist,
      void(const ClangBackEnd::ProjectPartsDoNotExistCommand &command));
};

#endif // MOCKIPCLIENT_H

==> qt-creator-opensource-src-3.6.1.tar.gz: qt-creator-opensource-src-3.6.1/tests/unit/unittest/mockipclient.h <==
/****************************************************************************
**
** Copyright (C) 2015 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt.io/licensing
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://www.qt.io/licensing.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef MOCKIPCLIENT_H
#define MOCKIPCLIENT_H

#include <ipcclientinterface.h>

#include <gmock/gmock.h>
#include <gmock/gmock-matchers.h>
#include <gtest/gtest.h>
#include "gtest-qt-printing.h"

class MockIpcClient : public ClangBackEnd::IpcClientInterface {
public:
    MOCK_METHOD0(alive,
                 void());
    MOCK_METHOD1(echo,
                 void(const ClangBackEnd::EchoMessage &message));
    MOCK_METHOD1(codeCompleted,
                 void(const ClangBackEnd::CodeCompletedMessage &message));
    MOCK_METHOD1(translationUnitDoesNotExist,
                 void(const ClangBackEnd::TranslationUnitDoesNotExistMessage &message));
    MOCK_METHOD1(projectPartsDoNotExist,
                 void(const ClangBackEnd::ProjectPartsDoNotExistMessage &message));
    MOCK_METHOD1(diagnosticsChanged,
                 void(const ClangBackEnd::DiagnosticsChangedMessage &message));
    MOCK_METHOD1(highlightingChanged,
                 void(const ClangBackEnd::HighlightingChangedMessage &message));
};

#endif // MOCKIPCLIENT_H
